@@ -19,25 +19,25 @@ MenvU_sim <- function(n, p, u, Omega=NULL, Omega0=NULL, Phi=NULL) {
 
   if (is.null(Phi)) {
     Phi <- matrix(runif(u^2), u, u)
-    Phi <- Phi %*% t(Phi)
+    Phi <- tcrossprod(Phi)
   }
 
   if (is.null(Omega)) {
       Omega <- matrix(runif(u^2), u, u)
-      Omega <- Omega %*% t(Omega)
+      Omega <- tcrossprod(Omega)
   }
 
   if (is.null(Omega0)) {
     Omega0 <- matrix(runif((p-u)^2),p-u,p-u)
-    Omega0 <- Omega0 %*% t(Omega0)
+    Omega0 <- tcrossprod(Omega0)
   }
   M <- Gamma %*% Omega %*% t(Gamma) + Gamma0 %*% Omega0 %*% t(Gamma0)
   U <- Gamma %*% Phi %*% t(Gamma)
 
   X <- MASS::mvrnorm(n, mu = rep(0, p), Sigma = M)
   Y <- MASS::mvrnorm(n, mu = rep(0, p), Sigma = U)
-  Mhat <- (t(X) %*% X)/n
-  Uhat <- (t(Y) %*% Y)/n
+  Mhat <- (crossprod(X))/n
+  Uhat <- (crossprod(Y))/n
 
   return(list(Mhat=Mhat, Uhat=Uhat, Gamma=Gamma))
 }
