@@ -19,11 +19,11 @@
 #' @param u The structural dimension of envelopes at each mode, a vector with the same length as r.
 #' @param n The sample size.
 #' @return
-#' \item{Xn}{The predictor of dimension \eqn{p\times n}}
-#' \item{Yn}{The response of dimension \eqn{r_1\times \cdots\times r_m \times n}}
+#' \item{x}{The predictor of dimension \eqn{p\times n}}
+#' \item{y}{The response of dimension \eqn{r_1\times \cdots\times r_m \times n}}
 #' \item{Gamma}{The envelope subspace basis of dimension \eqn{r_k \times u_k, \ k=1,\ldots,m}}
 #' \item{coefficients}{The tensor coefficients of dimension \eqn{r_1\times \cdots\times r_m \times p}}
-#' \item{Sigma}{The covariance matrix of error}
+#' \item{Sigma}{A lists of estimated covariance matrices at each mode for the error term, i.e., \eqn{\boldsymbol{\Sigma}_1,\dots,\boldsymbol{\Sigma}_m}.}
 #' \item{p, r, u}{The input \code{p,r,u}}
 #'
 #' @examples
@@ -32,9 +32,11 @@
 #' p <- 5
 #' n <- 100
 #' dat <- TRR_sim(r = r, p = p, u = u, n = n)
-#' Xn <- dat$Xn
-#' Yn <- dat$Yn
-#' @seealso \code{\link{TPR_sim}}.
+#' x <- dat$x
+#' y <- dat$y
+#' fit_std <- TRR.fit(x, y, method="standard")
+#'
+#' @seealso \code{\link{TPR.fit}, \link{TPR_sim}}.
 #' @references Li L, Zhang X (2017). “Parsimonious Tensor Response Regression.” Journal of the American Statistical Association, 112(519), 1131–1146.
 
 #' @export
@@ -51,9 +53,9 @@ TRR_sim <- function(r, p, u, n){
     Gamma[[i]] <- qr.Q(qr(tmp))
     Gamma0[[i]] <- qr.Q(qr(Gamma[[i]]),complete=TRUE)[,(u[i]+1):r[i]]
     A <- matrix(runif(u[i]^2), u[i], u[i])
-    Omega[[i]] <- A %*% t(A)
+    Omega[[i]] <- tcrossprod(A)
     A <- matrix(runif((r[i]-u[i])^2), (r[i]-u[i]), (r[i]-u[i]))
-    Omega0[[i]] <- A %*% t(A)
+    Omega0[[i]] <- tcrossprod(A)
     Sig[[i]] <- Gamma[[i]] %*% Omega[[i]] %*% t(Gamma[[i]])+
       Gamma0[[i]] %*% Omega0[[i]] %*% t(Gamma0[[i]])
     Sig[[i]] <- 10*Sig[[i]]/norm(Sig[[i]], type="F")+0.01*diag(r[i])
@@ -62,12 +64,12 @@ TRR_sim <- function(r, p, u, n){
   eta <- array(runif(prod(u)*p), c(u, p))
   eta <- rTensor::as.tensor(eta)
   B <- rTensor::ttl(eta, Gamma, ms=1:m)
-  Xn <- matrix(rnorm(p*n), p, n)
+  x <- matrix(rnorm(p*n), p, n)
   Epsilon <- array(rnorm(prod(r)*n), c(r, n))
   Epsilon <- rTensor::as.tensor(Epsilon)
   Epsilon <- rTensor::ttl(Epsilon, Sigsqrtm, ms=1:m)
-  Yn <- Epsilon + rTensor::ttm(B, t(Xn), m+1)
+  y <- Epsilon + rTensor::ttm(B, t(x), m+1)
 
-  output <- list(Xn = Xn, Yn = Yn, Gamma = Gamma, coefficients = B, Sigma = Sig, p = p, r = r, u = u)
+  output <- list(x = x, y = y, Gamma = Gamma, coefficients = B, Sigma = Sig, p = p, r = r, u = u)
   output
 }
